@@ -1,10 +1,12 @@
 import random
 import time
+
 from colorama import Fore
+
 from progress_table import ProgressTable
 
-progress = ProgressTable(columns=["step", "x", "x squared"])
-progress.add_column("x root", color=Fore.RED)
+progress = ProgressTable(columns=["step", "x", "x squared"], default_format_decimal_places=10)
+progress.add_column("x root", color=Fore.RED, width=12)
 
 for step in range(20):
     progress["step"] = step  # insert step value in the current row
@@ -23,4 +25,4 @@ progress.close()
 # export your data
 data = progress.to_list()
 pandas_df = progress.to_df()
-np_array = progress.to_numpy()
\ No newline at end of file
+np_array = progress.to_numpy()
